"""A collection of constants relating to dataframe columns."""

DELIMITER = "_"
LAG_COLUMN = "lag"
TRANSFORM_COLUMN = "transform"
DAYS_COLUMN_SUFFIX = "days"
ALL_SUFFIX = "all"
COUNT_WINDOW_FUNCTION = "count"
SUM_WINDOW_FUNCTION = "sum"
MEAN_WINDOW_FUNCTION = "mean"
MEDIAN_WINDOW_FUNCTION = "median"
VAR_WINDOW_FUNCTION = "var"
STD_WINDOW_FUNCTION = "std"
MIN_WINDOW_FUNCTION = "min"
MAX_WINDOW_FUNCTION = "max"
SKEW_WINDOW_FUNCTION = "skew"
KURT_WINDOW_FUNCTION = "kurt"
SEM_WINDOW_FUNCTION = "sem"
RANK_WINDOW_FUNCTION = "rank"
WINDOW_FUNCTIONS = [
    COUNT_WINDOW_FUNCTION,
    SUM_WINDOW_FUNCTION,
    MEAN_WINDOW_FUNCTION,
    MEDIAN_WINDOW_FUNCTION,
    VAR_WINDOW_FUNCTION,
    STD_WINDOW_FUNCTION,
    MIN_WINDOW_FUNCTION,
    MAX_WINDOW_FUNCTION,
    SKEW_WINDOW_FUNCTION,
    KURT_WINDOW_FUNCTION,
    SEM_WINDOW_FUNCTION,
    RANK_WINDOW_FUNCTION,
]
